The maps in this directory are generated in December 5, 2020.
We don't guarantee the identity between maps generated by procedural generation and maps in here. In future development, the generated maps may become different than here.
We may update the pre-generated maps set in future.

Please refer to `pgdrive/utils/generate_maps.py` to see the code generate the maps here.